<?php

namespace Litepie\Master\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Master\Interfaces\MasterRepositoryInterface;

class MasterPublicController extends BaseController
{
    // use MasterWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Master\Interfaces\MasterRepositoryInterface $master
     *
     * @return type
     */
    public function __construct(MasterRepositoryInterface $master)
    {
        $this->repository = $master;
        parent::__construct();
    }

    /**
     * Show master's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $masters = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$master::$master.names'))
            ->view('$master::public.master.index')
            ->data(compact('$masters'))
            ->output();
    }

    /**
     * Show master's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $masters = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$master::$master.names'))
            ->view('$master::public.master.index')
            ->data(compact('$masters'))
            ->output();
    }

    /**
     * Show master.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $master = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$master->name . trans('$master::$master.name'))
            ->view('$master::public.master.show')
            ->data(compact('$master'))
            ->output();
    }

}
